{% extends 'bootstrap/base.html' %}
{% block title %}Unauthorized{% endblock %}
{% block body %}
    <div class="container">
        <div class="jumbotron text-center">
            <h1>Unauthorized</h1>
            <p>Please contact with the owner of storage to get credentials.</p>
        </div>
    </div>
{% endblock %}