{% extends 'bootstrap/base.html' %}
{% block title %} Success! {% endblock %}
{% block content %}
    <div class="container">
        <h2 class="alert alert-success text-center"><span class="glyphicon glyphicon-ok-circle pull-left"></span> Your files are sent.</h2>
    </div>
{% endblock %}